# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `LightPath.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'LightPathExcitationFilterLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPathExcitationFilterLink = IcePy.declareClass('::omero::model::LightPathExcitationFilterLink')
    _M_omero.model._t_LightPathExcitationFilterLinkPrx = IcePy.declareProxy('::omero::model::LightPathExcitationFilterLink')

if 'Filter' not in _M_omero.model.__dict__:
    _M_omero.model._t_Filter = IcePy.declareClass('::omero::model::Filter')
    _M_omero.model._t_FilterPrx = IcePy.declareProxy('::omero::model::Filter')

if 'Dichroic' not in _M_omero.model.__dict__:
    _M_omero.model._t_Dichroic = IcePy.declareClass('::omero::model::Dichroic')
    _M_omero.model._t_DichroicPrx = IcePy.declareProxy('::omero::model::Dichroic')

if 'LightPathEmissionFilterLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPathEmissionFilterLink = IcePy.declareClass('::omero::model::LightPathEmissionFilterLink')
    _M_omero.model._t_LightPathEmissionFilterLinkPrx = IcePy.declareProxy('::omero::model::LightPathEmissionFilterLink')

if 'LightPathAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPathAnnotationLink = IcePy.declareClass('::omero::model::LightPathAnnotationLink')
    _M_omero.model._t_LightPathAnnotationLinkPrx = IcePy.declareProxy('::omero::model::LightPathAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_LightPathExcitationFilterLinkSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPathExcitationFilterLinkSeq = IcePy.defineSequence('::omero::model::LightPathExcitationFilterLinkSeq', (), _M_omero.model._t_LightPathExcitationFilterLink)

if '_t_LightPathLinkedExcitationFilterSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPathLinkedExcitationFilterSeq = IcePy.defineSequence('::omero::model::LightPathLinkedExcitationFilterSeq', (), _M_omero.model._t_Filter)

if '_t_LightPathEmissionFilterLinkSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPathEmissionFilterLinkSeq = IcePy.defineSequence('::omero::model::LightPathEmissionFilterLinkSeq', (), _M_omero.model._t_LightPathEmissionFilterLink)

if '_t_LightPathLinkedEmissionFilterSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPathLinkedEmissionFilterSeq = IcePy.defineSequence('::omero::model::LightPathLinkedEmissionFilterSeq', (), _M_omero.model._t_Filter)

if '_t_LightPathAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPathAnnotationLinksSeq = IcePy.defineSequence('::omero::model::LightPathAnnotationLinksSeq', (), _M_omero.model._t_LightPathAnnotationLink)

if '_t_LightPathLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPathLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::LightPathLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'LightPath' not in _M_omero.model.__dict__:
    _M_omero.model.LightPath = Ice.createTempClass()
    class LightPath(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _excitationFilterLinkSeq=None, _excitationFilterLinkLoaded=False, _excitationFilterLinkCountPerOwner=None, _dichroic=None, _emissionFilterLinkSeq=None, _emissionFilterLinkLoaded=False, _emissionFilterLinkCountPerOwner=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None):
            if Ice.getType(self) == _M_omero.model.LightPath:
                raise RuntimeError('omero.model.LightPath is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._excitationFilterLinkSeq = _excitationFilterLinkSeq
            self._excitationFilterLinkLoaded = _excitationFilterLinkLoaded
            self._excitationFilterLinkCountPerOwner = _excitationFilterLinkCountPerOwner
            self._dichroic = _dichroic
            self._emissionFilterLinkSeq = _emissionFilterLinkSeq
            self._emissionFilterLinkLoaded = _emissionFilterLinkLoaded
            self._emissionFilterLinkCountPerOwner = _emissionFilterLinkCountPerOwner
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::LightPath')

        def ice_id(self, current=None):
            return '::omero::model::LightPath'

        def ice_staticId():
            return '::omero::model::LightPath'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def unloadExcitationFilterLink(self, current=None):
            pass

        def sizeOfExcitationFilterLink(self, current=None):
            pass

        def copyExcitationFilterLink(self, current=None):
            pass

        def addLightPathExcitationFilterLink(self, target, current=None):
            pass

        def addAllLightPathExcitationFilterLinkSet(self, targets, current=None):
            pass

        def removeLightPathExcitationFilterLink(self, theTarget, current=None):
            pass

        def removeAllLightPathExcitationFilterLinkSet(self, targets, current=None):
            pass

        def clearExcitationFilterLink(self, current=None):
            pass

        def reloadExcitationFilterLink(self, toCopy, current=None):
            pass

        def getLightPathExcitationFilterLink(self, index, current=None):
            pass

        def setLightPathExcitationFilterLink(self, index, theElement, current=None):
            pass

        def getPrimaryLightPathExcitationFilterLink(self, current=None):
            pass

        def setPrimaryLightPathExcitationFilterLink(self, theElement, current=None):
            pass

        def getExcitationFilterLinkCountPerOwner(self, current=None):
            pass

        def linkExcitationFilter(self, addition, current=None):
            pass

        def addLightPathExcitationFilterLinkToBoth(self, link, bothSides, current=None):
            pass

        def findLightPathExcitationFilterLink(self, removal, current=None):
            pass

        def unlinkExcitationFilter(self, removal, current=None):
            pass

        def removeLightPathExcitationFilterLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedExcitationFilterList(self, current=None):
            pass

        def getDichroic(self, current=None):
            pass

        def setDichroic(self, theDichroic, current=None):
            pass

        def unloadEmissionFilterLink(self, current=None):
            pass

        def sizeOfEmissionFilterLink(self, current=None):
            pass

        def copyEmissionFilterLink(self, current=None):
            pass

        def addLightPathEmissionFilterLink(self, target, current=None):
            pass

        def addAllLightPathEmissionFilterLinkSet(self, targets, current=None):
            pass

        def removeLightPathEmissionFilterLink(self, theTarget, current=None):
            pass

        def removeAllLightPathEmissionFilterLinkSet(self, targets, current=None):
            pass

        def clearEmissionFilterLink(self, current=None):
            pass

        def reloadEmissionFilterLink(self, toCopy, current=None):
            pass

        def getEmissionFilterLinkCountPerOwner(self, current=None):
            pass

        def linkEmissionFilter(self, addition, current=None):
            pass

        def addLightPathEmissionFilterLinkToBoth(self, link, bothSides, current=None):
            pass

        def findLightPathEmissionFilterLink(self, removal, current=None):
            pass

        def unlinkEmissionFilter(self, removal, current=None):
            pass

        def removeLightPathEmissionFilterLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedEmissionFilterList(self, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addLightPathAnnotationLink(self, target, current=None):
            pass

        def addAllLightPathAnnotationLinkSet(self, targets, current=None):
            pass

        def removeLightPathAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllLightPathAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addLightPathAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findLightPathAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeLightPathAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_LightPath)

        __repr__ = __str__

    _M_omero.model.LightPathPrx = Ice.createTempClass()
    class LightPathPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.LightPath._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.LightPath._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.LightPath._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.LightPath._op_setVersion.end(self, _r)

        def unloadExcitationFilterLink(self, _ctx=None):
            return _M_omero.model.LightPath._op_unloadExcitationFilterLink.invoke(self, ((), _ctx))

        def begin_unloadExcitationFilterLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_unloadExcitationFilterLink.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_unloadExcitationFilterLink.end(self, _r)

        def sizeOfExcitationFilterLink(self, _ctx=None):
            return _M_omero.model.LightPath._op_sizeOfExcitationFilterLink.invoke(self, ((), _ctx))

        def begin_sizeOfExcitationFilterLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_sizeOfExcitationFilterLink.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_sizeOfExcitationFilterLink.end(self, _r)

        def copyExcitationFilterLink(self, _ctx=None):
            return _M_omero.model.LightPath._op_copyExcitationFilterLink.invoke(self, ((), _ctx))

        def begin_copyExcitationFilterLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_copyExcitationFilterLink.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_copyExcitationFilterLink.end(self, _r)

        def addLightPathExcitationFilterLink(self, target, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathExcitationFilterLink.invoke(self, ((target, ), _ctx))

        def begin_addLightPathExcitationFilterLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathExcitationFilterLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addLightPathExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_addLightPathExcitationFilterLink.end(self, _r)

        def addAllLightPathExcitationFilterLinkSet(self, targets, _ctx=None):
            return _M_omero.model.LightPath._op_addAllLightPathExcitationFilterLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllLightPathExcitationFilterLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_addAllLightPathExcitationFilterLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllLightPathExcitationFilterLinkSet(self, _r):
            return _M_omero.model.LightPath._op_addAllLightPathExcitationFilterLinkSet.end(self, _r)

        def removeLightPathExcitationFilterLink(self, theTarget, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathExcitationFilterLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeLightPathExcitationFilterLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathExcitationFilterLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeLightPathExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_removeLightPathExcitationFilterLink.end(self, _r)

        def removeAllLightPathExcitationFilterLinkSet(self, targets, _ctx=None):
            return _M_omero.model.LightPath._op_removeAllLightPathExcitationFilterLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllLightPathExcitationFilterLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_removeAllLightPathExcitationFilterLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllLightPathExcitationFilterLinkSet(self, _r):
            return _M_omero.model.LightPath._op_removeAllLightPathExcitationFilterLinkSet.end(self, _r)

        def clearExcitationFilterLink(self, _ctx=None):
            return _M_omero.model.LightPath._op_clearExcitationFilterLink.invoke(self, ((), _ctx))

        def begin_clearExcitationFilterLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_clearExcitationFilterLink.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_clearExcitationFilterLink.end(self, _r)

        def reloadExcitationFilterLink(self, toCopy, _ctx=None):
            return _M_omero.model.LightPath._op_reloadExcitationFilterLink.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadExcitationFilterLink(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_reloadExcitationFilterLink.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_reloadExcitationFilterLink.end(self, _r)

        def getLightPathExcitationFilterLink(self, index, _ctx=None):
            return _M_omero.model.LightPath._op_getLightPathExcitationFilterLink.invoke(self, ((index, ), _ctx))

        def begin_getLightPathExcitationFilterLink(self, index, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_getLightPathExcitationFilterLink.begin(self, ((index, ), _response, _ex, _sent, _ctx))

        def end_getLightPathExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_getLightPathExcitationFilterLink.end(self, _r)

        def setLightPathExcitationFilterLink(self, index, theElement, _ctx=None):
            return _M_omero.model.LightPath._op_setLightPathExcitationFilterLink.invoke(self, ((index, theElement), _ctx))

        def begin_setLightPathExcitationFilterLink(self, index, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_setLightPathExcitationFilterLink.begin(self, ((index, theElement), _response, _ex, _sent, _ctx))

        def end_setLightPathExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_setLightPathExcitationFilterLink.end(self, _r)

        def getPrimaryLightPathExcitationFilterLink(self, _ctx=None):
            return _M_omero.model.LightPath._op_getPrimaryLightPathExcitationFilterLink.invoke(self, ((), _ctx))

        def begin_getPrimaryLightPathExcitationFilterLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_getPrimaryLightPathExcitationFilterLink.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPrimaryLightPathExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_getPrimaryLightPathExcitationFilterLink.end(self, _r)

        def setPrimaryLightPathExcitationFilterLink(self, theElement, _ctx=None):
            return _M_omero.model.LightPath._op_setPrimaryLightPathExcitationFilterLink.invoke(self, ((theElement, ), _ctx))

        def begin_setPrimaryLightPathExcitationFilterLink(self, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_setPrimaryLightPathExcitationFilterLink.begin(self, ((theElement, ), _response, _ex, _sent, _ctx))

        def end_setPrimaryLightPathExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_setPrimaryLightPathExcitationFilterLink.end(self, _r)

        def getExcitationFilterLinkCountPerOwner(self, _ctx=None):
            return _M_omero.model.LightPath._op_getExcitationFilterLinkCountPerOwner.invoke(self, ((), _ctx))

        def begin_getExcitationFilterLinkCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_getExcitationFilterLinkCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getExcitationFilterLinkCountPerOwner(self, _r):
            return _M_omero.model.LightPath._op_getExcitationFilterLinkCountPerOwner.end(self, _r)

        def linkExcitationFilter(self, addition, _ctx=None):
            return _M_omero.model.LightPath._op_linkExcitationFilter.invoke(self, ((addition, ), _ctx))

        def begin_linkExcitationFilter(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_linkExcitationFilter.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkExcitationFilter(self, _r):
            return _M_omero.model.LightPath._op_linkExcitationFilter.end(self, _r)

        def addLightPathExcitationFilterLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathExcitationFilterLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addLightPathExcitationFilterLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathExcitationFilterLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addLightPathExcitationFilterLinkToBoth(self, _r):
            return _M_omero.model.LightPath._op_addLightPathExcitationFilterLinkToBoth.end(self, _r)

        def findLightPathExcitationFilterLink(self, removal, _ctx=None):
            return _M_omero.model.LightPath._op_findLightPathExcitationFilterLink.invoke(self, ((removal, ), _ctx))

        def begin_findLightPathExcitationFilterLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_findLightPathExcitationFilterLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findLightPathExcitationFilterLink(self, _r):
            return _M_omero.model.LightPath._op_findLightPathExcitationFilterLink.end(self, _r)

        def unlinkExcitationFilter(self, removal, _ctx=None):
            return _M_omero.model.LightPath._op_unlinkExcitationFilter.invoke(self, ((removal, ), _ctx))

        def begin_unlinkExcitationFilter(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_unlinkExcitationFilter.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkExcitationFilter(self, _r):
            return _M_omero.model.LightPath._op_unlinkExcitationFilter.end(self, _r)

        def removeLightPathExcitationFilterLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathExcitationFilterLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeLightPathExcitationFilterLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathExcitationFilterLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeLightPathExcitationFilterLinkFromBoth(self, _r):
            return _M_omero.model.LightPath._op_removeLightPathExcitationFilterLinkFromBoth.end(self, _r)

        def linkedExcitationFilterList(self, _ctx=None):
            return _M_omero.model.LightPath._op_linkedExcitationFilterList.invoke(self, ((), _ctx))

        def begin_linkedExcitationFilterList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_linkedExcitationFilterList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedExcitationFilterList(self, _r):
            return _M_omero.model.LightPath._op_linkedExcitationFilterList.end(self, _r)

        def getDichroic(self, _ctx=None):
            return _M_omero.model.LightPath._op_getDichroic.invoke(self, ((), _ctx))

        def begin_getDichroic(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_getDichroic.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDichroic(self, _r):
            return _M_omero.model.LightPath._op_getDichroic.end(self, _r)

        def setDichroic(self, theDichroic, _ctx=None):
            return _M_omero.model.LightPath._op_setDichroic.invoke(self, ((theDichroic, ), _ctx))

        def begin_setDichroic(self, theDichroic, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_setDichroic.begin(self, ((theDichroic, ), _response, _ex, _sent, _ctx))

        def end_setDichroic(self, _r):
            return _M_omero.model.LightPath._op_setDichroic.end(self, _r)

        def unloadEmissionFilterLink(self, _ctx=None):
            return _M_omero.model.LightPath._op_unloadEmissionFilterLink.invoke(self, ((), _ctx))

        def begin_unloadEmissionFilterLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_unloadEmissionFilterLink.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadEmissionFilterLink(self, _r):
            return _M_omero.model.LightPath._op_unloadEmissionFilterLink.end(self, _r)

        def sizeOfEmissionFilterLink(self, _ctx=None):
            return _M_omero.model.LightPath._op_sizeOfEmissionFilterLink.invoke(self, ((), _ctx))

        def begin_sizeOfEmissionFilterLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_sizeOfEmissionFilterLink.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfEmissionFilterLink(self, _r):
            return _M_omero.model.LightPath._op_sizeOfEmissionFilterLink.end(self, _r)

        def copyEmissionFilterLink(self, _ctx=None):
            return _M_omero.model.LightPath._op_copyEmissionFilterLink.invoke(self, ((), _ctx))

        def begin_copyEmissionFilterLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_copyEmissionFilterLink.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyEmissionFilterLink(self, _r):
            return _M_omero.model.LightPath._op_copyEmissionFilterLink.end(self, _r)

        def addLightPathEmissionFilterLink(self, target, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathEmissionFilterLink.invoke(self, ((target, ), _ctx))

        def begin_addLightPathEmissionFilterLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathEmissionFilterLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addLightPathEmissionFilterLink(self, _r):
            return _M_omero.model.LightPath._op_addLightPathEmissionFilterLink.end(self, _r)

        def addAllLightPathEmissionFilterLinkSet(self, targets, _ctx=None):
            return _M_omero.model.LightPath._op_addAllLightPathEmissionFilterLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllLightPathEmissionFilterLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_addAllLightPathEmissionFilterLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllLightPathEmissionFilterLinkSet(self, _r):
            return _M_omero.model.LightPath._op_addAllLightPathEmissionFilterLinkSet.end(self, _r)

        def removeLightPathEmissionFilterLink(self, theTarget, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathEmissionFilterLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeLightPathEmissionFilterLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathEmissionFilterLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeLightPathEmissionFilterLink(self, _r):
            return _M_omero.model.LightPath._op_removeLightPathEmissionFilterLink.end(self, _r)

        def removeAllLightPathEmissionFilterLinkSet(self, targets, _ctx=None):
            return _M_omero.model.LightPath._op_removeAllLightPathEmissionFilterLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllLightPathEmissionFilterLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_removeAllLightPathEmissionFilterLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllLightPathEmissionFilterLinkSet(self, _r):
            return _M_omero.model.LightPath._op_removeAllLightPathEmissionFilterLinkSet.end(self, _r)

        def clearEmissionFilterLink(self, _ctx=None):
            return _M_omero.model.LightPath._op_clearEmissionFilterLink.invoke(self, ((), _ctx))

        def begin_clearEmissionFilterLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_clearEmissionFilterLink.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearEmissionFilterLink(self, _r):
            return _M_omero.model.LightPath._op_clearEmissionFilterLink.end(self, _r)

        def reloadEmissionFilterLink(self, toCopy, _ctx=None):
            return _M_omero.model.LightPath._op_reloadEmissionFilterLink.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadEmissionFilterLink(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_reloadEmissionFilterLink.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadEmissionFilterLink(self, _r):
            return _M_omero.model.LightPath._op_reloadEmissionFilterLink.end(self, _r)

        def getEmissionFilterLinkCountPerOwner(self, _ctx=None):
            return _M_omero.model.LightPath._op_getEmissionFilterLinkCountPerOwner.invoke(self, ((), _ctx))

        def begin_getEmissionFilterLinkCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_getEmissionFilterLinkCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getEmissionFilterLinkCountPerOwner(self, _r):
            return _M_omero.model.LightPath._op_getEmissionFilterLinkCountPerOwner.end(self, _r)

        def linkEmissionFilter(self, addition, _ctx=None):
            return _M_omero.model.LightPath._op_linkEmissionFilter.invoke(self, ((addition, ), _ctx))

        def begin_linkEmissionFilter(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_linkEmissionFilter.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkEmissionFilter(self, _r):
            return _M_omero.model.LightPath._op_linkEmissionFilter.end(self, _r)

        def addLightPathEmissionFilterLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathEmissionFilterLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addLightPathEmissionFilterLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathEmissionFilterLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addLightPathEmissionFilterLinkToBoth(self, _r):
            return _M_omero.model.LightPath._op_addLightPathEmissionFilterLinkToBoth.end(self, _r)

        def findLightPathEmissionFilterLink(self, removal, _ctx=None):
            return _M_omero.model.LightPath._op_findLightPathEmissionFilterLink.invoke(self, ((removal, ), _ctx))

        def begin_findLightPathEmissionFilterLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_findLightPathEmissionFilterLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findLightPathEmissionFilterLink(self, _r):
            return _M_omero.model.LightPath._op_findLightPathEmissionFilterLink.end(self, _r)

        def unlinkEmissionFilter(self, removal, _ctx=None):
            return _M_omero.model.LightPath._op_unlinkEmissionFilter.invoke(self, ((removal, ), _ctx))

        def begin_unlinkEmissionFilter(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_unlinkEmissionFilter.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkEmissionFilter(self, _r):
            return _M_omero.model.LightPath._op_unlinkEmissionFilter.end(self, _r)

        def removeLightPathEmissionFilterLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathEmissionFilterLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeLightPathEmissionFilterLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathEmissionFilterLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeLightPathEmissionFilterLinkFromBoth(self, _r):
            return _M_omero.model.LightPath._op_removeLightPathEmissionFilterLinkFromBoth.end(self, _r)

        def linkedEmissionFilterList(self, _ctx=None):
            return _M_omero.model.LightPath._op_linkedEmissionFilterList.invoke(self, ((), _ctx))

        def begin_linkedEmissionFilterList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_linkedEmissionFilterList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedEmissionFilterList(self, _r):
            return _M_omero.model.LightPath._op_linkedEmissionFilterList.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.LightPath._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.LightPath._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.LightPath._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.LightPath._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.LightPath._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.LightPath._op_copyAnnotationLinks.end(self, _r)

        def addLightPathAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addLightPathAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addLightPathAnnotationLink(self, _r):
            return _M_omero.model.LightPath._op_addLightPathAnnotationLink.end(self, _r)

        def addAllLightPathAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.LightPath._op_addAllLightPathAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllLightPathAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_addAllLightPathAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllLightPathAnnotationLinkSet(self, _r):
            return _M_omero.model.LightPath._op_addAllLightPathAnnotationLinkSet.end(self, _r)

        def removeLightPathAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeLightPathAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeLightPathAnnotationLink(self, _r):
            return _M_omero.model.LightPath._op_removeLightPathAnnotationLink.end(self, _r)

        def removeAllLightPathAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.LightPath._op_removeAllLightPathAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllLightPathAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_removeAllLightPathAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllLightPathAnnotationLinkSet(self, _r):
            return _M_omero.model.LightPath._op_removeAllLightPathAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.LightPath._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.LightPath._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.LightPath._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.LightPath._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.LightPath._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.LightPath._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.LightPath._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.LightPath._op_linkAnnotation.end(self, _r)

        def addLightPathAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addLightPathAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_addLightPathAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addLightPathAnnotationLinkToBoth(self, _r):
            return _M_omero.model.LightPath._op_addLightPathAnnotationLinkToBoth.end(self, _r)

        def findLightPathAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.LightPath._op_findLightPathAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findLightPathAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_findLightPathAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findLightPathAnnotationLink(self, _r):
            return _M_omero.model.LightPath._op_findLightPathAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.LightPath._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.LightPath._op_unlinkAnnotation.end(self, _r)

        def removeLightPathAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeLightPathAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_removeLightPathAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeLightPathAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.LightPath._op_removeLightPathAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.LightPath._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightPath._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.LightPath._op_linkedAnnotationList.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.LightPathPrx.ice_checkedCast(proxy, '::omero::model::LightPath', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.LightPathPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::LightPath'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_LightPathPrx = IcePy.defineProxy('::omero::model::LightPath', LightPathPrx)

    _M_omero.model._t_LightPath = IcePy.declareClass('::omero::model::LightPath')

    _M_omero.model._t_LightPath = IcePy.defineClass('::omero::model::LightPath', LightPath, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_excitationFilterLinkSeq', (), _M_omero.model._t_LightPathExcitationFilterLinkSeq, False, 0),
        ('_excitationFilterLinkLoaded', (), IcePy._t_bool, False, 0),
        ('_excitationFilterLinkCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_dichroic', (), _M_omero.model._t_Dichroic, False, 0),
        ('_emissionFilterLinkSeq', (), _M_omero.model._t_LightPathEmissionFilterLinkSeq, False, 0),
        ('_emissionFilterLinkLoaded', (), IcePy._t_bool, False, 0),
        ('_emissionFilterLinkCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_LightPathAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0)
    ))
    LightPath._ice_type = _M_omero.model._t_LightPath

    LightPath._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    LightPath._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    LightPath._op_unloadExcitationFilterLink = IcePy.Operation('unloadExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    LightPath._op_sizeOfExcitationFilterLink = IcePy.Operation('sizeOfExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    LightPath._op_copyExcitationFilterLink = IcePy.Operation('copyExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightPathExcitationFilterLinkSeq, False, 0), ())
    LightPath._op_addLightPathExcitationFilterLink = IcePy.Operation('addLightPathExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0),), (), None, ())
    LightPath._op_addAllLightPathExcitationFilterLinkSet = IcePy.Operation('addAllLightPathExcitationFilterLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathExcitationFilterLinkSeq, False, 0),), (), None, ())
    LightPath._op_removeLightPathExcitationFilterLink = IcePy.Operation('removeLightPathExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0),), (), None, ())
    LightPath._op_removeAllLightPathExcitationFilterLinkSet = IcePy.Operation('removeAllLightPathExcitationFilterLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathExcitationFilterLinkSeq, False, 0),), (), None, ())
    LightPath._op_clearExcitationFilterLink = IcePy.Operation('clearExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    LightPath._op_reloadExcitationFilterLink = IcePy.Operation('reloadExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPath, False, 0),), (), None, ())
    LightPath._op_getLightPathExcitationFilterLink = IcePy.Operation('getLightPathExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0),), (), ((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0), ())
    LightPath._op_setLightPathExcitationFilterLink = IcePy.Operation('setLightPathExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0)), (), ((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0), ())
    LightPath._op_getPrimaryLightPathExcitationFilterLink = IcePy.Operation('getPrimaryLightPathExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0), ())
    LightPath._op_setPrimaryLightPathExcitationFilterLink = IcePy.Operation('setPrimaryLightPathExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0),), (), ((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0), ())
    LightPath._op_getExcitationFilterLinkCountPerOwner = IcePy.Operation('getExcitationFilterLinkCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    LightPath._op_linkExcitationFilter = IcePy.Operation('linkExcitationFilter', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Filter, False, 0),), (), ((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0), ())
    LightPath._op_addLightPathExcitationFilterLinkToBoth = IcePy.Operation('addLightPathExcitationFilterLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    LightPath._op_findLightPathExcitationFilterLink = IcePy.Operation('findLightPathExcitationFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Filter, False, 0),), (), ((), _M_omero.model._t_LightPathExcitationFilterLinkSeq, False, 0), ())
    LightPath._op_unlinkExcitationFilter = IcePy.Operation('unlinkExcitationFilter', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Filter, False, 0),), (), None, ())
    LightPath._op_removeLightPathExcitationFilterLinkFromBoth = IcePy.Operation('removeLightPathExcitationFilterLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathExcitationFilterLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    LightPath._op_linkedExcitationFilterList = IcePy.Operation('linkedExcitationFilterList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightPathLinkedExcitationFilterSeq, False, 0), ())
    LightPath._op_getDichroic = IcePy.Operation('getDichroic', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Dichroic, False, 0), ())
    LightPath._op_setDichroic = IcePy.Operation('setDichroic', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Dichroic, False, 0),), (), None, ())
    LightPath._op_unloadEmissionFilterLink = IcePy.Operation('unloadEmissionFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    LightPath._op_sizeOfEmissionFilterLink = IcePy.Operation('sizeOfEmissionFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    LightPath._op_copyEmissionFilterLink = IcePy.Operation('copyEmissionFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightPathEmissionFilterLinkSeq, False, 0), ())
    LightPath._op_addLightPathEmissionFilterLink = IcePy.Operation('addLightPathEmissionFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathEmissionFilterLink, False, 0),), (), None, ())
    LightPath._op_addAllLightPathEmissionFilterLinkSet = IcePy.Operation('addAllLightPathEmissionFilterLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathEmissionFilterLinkSeq, False, 0),), (), None, ())
    LightPath._op_removeLightPathEmissionFilterLink = IcePy.Operation('removeLightPathEmissionFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathEmissionFilterLink, False, 0),), (), None, ())
    LightPath._op_removeAllLightPathEmissionFilterLinkSet = IcePy.Operation('removeAllLightPathEmissionFilterLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathEmissionFilterLinkSeq, False, 0),), (), None, ())
    LightPath._op_clearEmissionFilterLink = IcePy.Operation('clearEmissionFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    LightPath._op_reloadEmissionFilterLink = IcePy.Operation('reloadEmissionFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPath, False, 0),), (), None, ())
    LightPath._op_getEmissionFilterLinkCountPerOwner = IcePy.Operation('getEmissionFilterLinkCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    LightPath._op_linkEmissionFilter = IcePy.Operation('linkEmissionFilter', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Filter, False, 0),), (), ((), _M_omero.model._t_LightPathEmissionFilterLink, False, 0), ())
    LightPath._op_addLightPathEmissionFilterLinkToBoth = IcePy.Operation('addLightPathEmissionFilterLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathEmissionFilterLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    LightPath._op_findLightPathEmissionFilterLink = IcePy.Operation('findLightPathEmissionFilterLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Filter, False, 0),), (), ((), _M_omero.model._t_LightPathEmissionFilterLinkSeq, False, 0), ())
    LightPath._op_unlinkEmissionFilter = IcePy.Operation('unlinkEmissionFilter', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Filter, False, 0),), (), None, ())
    LightPath._op_removeLightPathEmissionFilterLinkFromBoth = IcePy.Operation('removeLightPathEmissionFilterLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathEmissionFilterLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    LightPath._op_linkedEmissionFilterList = IcePy.Operation('linkedEmissionFilterList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightPathLinkedEmissionFilterSeq, False, 0), ())
    LightPath._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    LightPath._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    LightPath._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightPathAnnotationLinksSeq, False, 0), ())
    LightPath._op_addLightPathAnnotationLink = IcePy.Operation('addLightPathAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathAnnotationLink, False, 0),), (), None, ())
    LightPath._op_addAllLightPathAnnotationLinkSet = IcePy.Operation('addAllLightPathAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathAnnotationLinksSeq, False, 0),), (), None, ())
    LightPath._op_removeLightPathAnnotationLink = IcePy.Operation('removeLightPathAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathAnnotationLink, False, 0),), (), None, ())
    LightPath._op_removeAllLightPathAnnotationLinkSet = IcePy.Operation('removeAllLightPathAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathAnnotationLinksSeq, False, 0),), (), None, ())
    LightPath._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    LightPath._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPath, False, 0),), (), None, ())
    LightPath._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    LightPath._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_LightPathAnnotationLink, False, 0), ())
    LightPath._op_addLightPathAnnotationLinkToBoth = IcePy.Operation('addLightPathAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    LightPath._op_findLightPathAnnotationLink = IcePy.Operation('findLightPathAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_LightPathAnnotationLinksSeq, False, 0), ())
    LightPath._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    LightPath._op_removeLightPathAnnotationLinkFromBoth = IcePy.Operation('removeLightPathAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPathAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    LightPath._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightPathLinkedAnnotationSeq, False, 0), ())

    _M_omero.model.LightPath = LightPath
    del LightPath

    _M_omero.model.LightPathPrx = LightPathPrx
    del LightPathPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Plate.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'ScreenPlateLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ScreenPlateLink = IcePy.declareClass('::omero::model::ScreenPlateLink')
    _M_omero.model._t_ScreenPlateLinkPrx = IcePy.declareProxy('::omero::model::ScreenPlateLink')

if 'Screen' not in _M_omero.model.__dict__:
    _M_omero.model._t_Screen = IcePy.declareClass('::omero::model::Screen')
    _M_omero.model._t_ScreenPrx = IcePy.declareProxy('::omero::model::Screen')

if 'Well' not in _M_omero.model.__dict__:
    _M_omero.model._t_Well = IcePy.declareClass('::omero::model::Well')
    _M_omero.model._t_WellPrx = IcePy.declareProxy('::omero::model::Well')

if 'PlateAcquisition' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateAcquisition = IcePy.declareClass('::omero::model::PlateAcquisition')
    _M_omero.model._t_PlateAcquisitionPrx = IcePy.declareProxy('::omero::model::PlateAcquisition')

if 'PlateAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateAnnotationLink = IcePy.declareClass('::omero::model::PlateAnnotationLink')
    _M_omero.model._t_PlateAnnotationLinkPrx = IcePy.declareProxy('::omero::model::PlateAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_PlateScreenLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateScreenLinksSeq = IcePy.defineSequence('::omero::model::PlateScreenLinksSeq', (), _M_omero.model._t_ScreenPlateLink)

if '_t_PlateLinkedScreenSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateLinkedScreenSeq = IcePy.defineSequence('::omero::model::PlateLinkedScreenSeq', (), _M_omero.model._t_Screen)

if '_t_PlateWellsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateWellsSeq = IcePy.defineSequence('::omero::model::PlateWellsSeq', (), _M_omero.model._t_Well)

if '_t_PlatePlateAcquisitionsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlatePlateAcquisitionsSeq = IcePy.defineSequence('::omero::model::PlatePlateAcquisitionsSeq', (), _M_omero.model._t_PlateAcquisition)

if '_t_PlateAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateAnnotationLinksSeq = IcePy.defineSequence('::omero::model::PlateAnnotationLinksSeq', (), _M_omero.model._t_PlateAnnotationLink)

if '_t_PlateLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::PlateLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Plate' not in _M_omero.model.__dict__:
    _M_omero.model.Plate = Ice.createTempClass()
    class Plate(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _defaultSample=None, _columnNamingConvention=None, _rowNamingConvention=None, _wellOriginX=None, _wellOriginY=None, _rows=None, _columns=None, _status=None, _externalIdentifier=None, _screenLinksSeq=None, _screenLinksLoaded=False, _screenLinksCountPerOwner=None, _wellsSeq=None, _wellsLoaded=False, _plateAcquisitionsSeq=None, _plateAcquisitionsLoaded=False, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _name=None, _description=None):
            if Ice.getType(self) == _M_omero.model.Plate:
                raise RuntimeError('omero.model.Plate is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._defaultSample = _defaultSample
            self._columnNamingConvention = _columnNamingConvention
            self._rowNamingConvention = _rowNamingConvention
            self._wellOriginX = _wellOriginX
            self._wellOriginY = _wellOriginY
            self._rows = _rows
            self._columns = _columns
            self._status = _status
            self._externalIdentifier = _externalIdentifier
            self._screenLinksSeq = _screenLinksSeq
            self._screenLinksLoaded = _screenLinksLoaded
            self._screenLinksCountPerOwner = _screenLinksCountPerOwner
            self._wellsSeq = _wellsSeq
            self._wellsLoaded = _wellsLoaded
            self._plateAcquisitionsSeq = _plateAcquisitionsSeq
            self._plateAcquisitionsLoaded = _plateAcquisitionsLoaded
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner
            self._name = _name
            self._description = _description

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Plate')

        def ice_id(self, current=None):
            return '::omero::model::Plate'

        def ice_staticId():
            return '::omero::model::Plate'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getDefaultSample(self, current=None):
            pass

        def setDefaultSample(self, theDefaultSample, current=None):
            pass

        def getColumnNamingConvention(self, current=None):
            pass

        def setColumnNamingConvention(self, theColumnNamingConvention, current=None):
            pass

        def getRowNamingConvention(self, current=None):
            pass

        def setRowNamingConvention(self, theRowNamingConvention, current=None):
            pass

        def getWellOriginX(self, current=None):
            pass

        def setWellOriginX(self, theWellOriginX, current=None):
            pass

        def getWellOriginY(self, current=None):
            pass

        def setWellOriginY(self, theWellOriginY, current=None):
            pass

        def getRows(self, current=None):
            pass

        def setRows(self, theRows, current=None):
            pass

        def getColumns(self, current=None):
            pass

        def setColumns(self, theColumns, current=None):
            pass

        def getStatus(self, current=None):
            pass

        def setStatus(self, theStatus, current=None):
            pass

        def getExternalIdentifier(self, current=None):
            pass

        def setExternalIdentifier(self, theExternalIdentifier, current=None):
            pass

        def unloadScreenLinks(self, current=None):
            pass

        def sizeOfScreenLinks(self, current=None):
            pass

        def copyScreenLinks(self, current=None):
            pass

        def addScreenPlateLink(self, target, current=None):
            pass

        def addAllScreenPlateLinkSet(self, targets, current=None):
            pass

        def removeScreenPlateLink(self, theTarget, current=None):
            pass

        def removeAllScreenPlateLinkSet(self, targets, current=None):
            pass

        def clearScreenLinks(self, current=None):
            pass

        def reloadScreenLinks(self, toCopy, current=None):
            pass

        def getScreenLinksCountPerOwner(self, current=None):
            pass

        def linkScreen(self, addition, current=None):
            pass

        def addScreenPlateLinkToBoth(self, link, bothSides, current=None):
            pass

        def findScreenPlateLink(self, removal, current=None):
            pass

        def unlinkScreen(self, removal, current=None):
            pass

        def removeScreenPlateLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedScreenList(self, current=None):
            pass

        def unloadWells(self, current=None):
            pass

        def sizeOfWells(self, current=None):
            pass

        def copyWells(self, current=None):
            pass

        def addWell(self, target, current=None):
            pass

        def addAllWellSet(self, targets, current=None):
            pass

        def removeWell(self, theTarget, current=None):
            pass

        def removeAllWellSet(self, targets, current=None):
            pass

        def clearWells(self, current=None):
            pass

        def reloadWells(self, toCopy, current=None):
            pass

        def unloadPlateAcquisitions(self, current=None):
            pass

        def sizeOfPlateAcquisitions(self, current=None):
            pass

        def copyPlateAcquisitions(self, current=None):
            pass

        def addPlateAcquisition(self, target, current=None):
            pass

        def addAllPlateAcquisitionSet(self, targets, current=None):
            pass

        def removePlateAcquisition(self, theTarget, current=None):
            pass

        def removeAllPlateAcquisitionSet(self, targets, current=None):
            pass

        def clearPlateAcquisitions(self, current=None):
            pass

        def reloadPlateAcquisitions(self, toCopy, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addPlateAnnotationLink(self, target, current=None):
            pass

        def addAllPlateAnnotationLinkSet(self, targets, current=None):
            pass

        def removePlateAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllPlateAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addPlateAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findPlateAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removePlateAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def getDescription(self, current=None):
            pass

        def setDescription(self, theDescription, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Plate)

        __repr__ = __str__

    _M_omero.model.PlatePrx = Ice.createTempClass()
    class PlatePrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Plate._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Plate._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Plate._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Plate._op_setVersion.end(self, _r)

        def getDefaultSample(self, _ctx=None):
            return _M_omero.model.Plate._op_getDefaultSample.invoke(self, ((), _ctx))

        def begin_getDefaultSample(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getDefaultSample.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDefaultSample(self, _r):
            return _M_omero.model.Plate._op_getDefaultSample.end(self, _r)

        def setDefaultSample(self, theDefaultSample, _ctx=None):
            return _M_omero.model.Plate._op_setDefaultSample.invoke(self, ((theDefaultSample, ), _ctx))

        def begin_setDefaultSample(self, theDefaultSample, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setDefaultSample.begin(self, ((theDefaultSample, ), _response, _ex, _sent, _ctx))

        def end_setDefaultSample(self, _r):
            return _M_omero.model.Plate._op_setDefaultSample.end(self, _r)

        def getColumnNamingConvention(self, _ctx=None):
            return _M_omero.model.Plate._op_getColumnNamingConvention.invoke(self, ((), _ctx))

        def begin_getColumnNamingConvention(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getColumnNamingConvention.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getColumnNamingConvention(self, _r):
            return _M_omero.model.Plate._op_getColumnNamingConvention.end(self, _r)

        def setColumnNamingConvention(self, theColumnNamingConvention, _ctx=None):
            return _M_omero.model.Plate._op_setColumnNamingConvention.invoke(self, ((theColumnNamingConvention, ), _ctx))

        def begin_setColumnNamingConvention(self, theColumnNamingConvention, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setColumnNamingConvention.begin(self, ((theColumnNamingConvention, ), _response, _ex, _sent, _ctx))

        def end_setColumnNamingConvention(self, _r):
            return _M_omero.model.Plate._op_setColumnNamingConvention.end(self, _r)

        def getRowNamingConvention(self, _ctx=None):
            return _M_omero.model.Plate._op_getRowNamingConvention.invoke(self, ((), _ctx))

        def begin_getRowNamingConvention(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getRowNamingConvention.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRowNamingConvention(self, _r):
            return _M_omero.model.Plate._op_getRowNamingConvention.end(self, _r)

        def setRowNamingConvention(self, theRowNamingConvention, _ctx=None):
            return _M_omero.model.Plate._op_setRowNamingConvention.invoke(self, ((theRowNamingConvention, ), _ctx))

        def begin_setRowNamingConvention(self, theRowNamingConvention, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setRowNamingConvention.begin(self, ((theRowNamingConvention, ), _response, _ex, _sent, _ctx))

        def end_setRowNamingConvention(self, _r):
            return _M_omero.model.Plate._op_setRowNamingConvention.end(self, _r)

        def getWellOriginX(self, _ctx=None):
            return _M_omero.model.Plate._op_getWellOriginX.invoke(self, ((), _ctx))

        def begin_getWellOriginX(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getWellOriginX.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getWellOriginX(self, _r):
            return _M_omero.model.Plate._op_getWellOriginX.end(self, _r)

        def setWellOriginX(self, theWellOriginX, _ctx=None):
            return _M_omero.model.Plate._op_setWellOriginX.invoke(self, ((theWellOriginX, ), _ctx))

        def begin_setWellOriginX(self, theWellOriginX, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setWellOriginX.begin(self, ((theWellOriginX, ), _response, _ex, _sent, _ctx))

        def end_setWellOriginX(self, _r):
            return _M_omero.model.Plate._op_setWellOriginX.end(self, _r)

        def getWellOriginY(self, _ctx=None):
            return _M_omero.model.Plate._op_getWellOriginY.invoke(self, ((), _ctx))

        def begin_getWellOriginY(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getWellOriginY.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getWellOriginY(self, _r):
            return _M_omero.model.Plate._op_getWellOriginY.end(self, _r)

        def setWellOriginY(self, theWellOriginY, _ctx=None):
            return _M_omero.model.Plate._op_setWellOriginY.invoke(self, ((theWellOriginY, ), _ctx))

        def begin_setWellOriginY(self, theWellOriginY, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setWellOriginY.begin(self, ((theWellOriginY, ), _response, _ex, _sent, _ctx))

        def end_setWellOriginY(self, _r):
            return _M_omero.model.Plate._op_setWellOriginY.end(self, _r)

        def getRows(self, _ctx=None):
            return _M_omero.model.Plate._op_getRows.invoke(self, ((), _ctx))

        def begin_getRows(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getRows.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRows(self, _r):
            return _M_omero.model.Plate._op_getRows.end(self, _r)

        def setRows(self, theRows, _ctx=None):
            return _M_omero.model.Plate._op_setRows.invoke(self, ((theRows, ), _ctx))

        def begin_setRows(self, theRows, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setRows.begin(self, ((theRows, ), _response, _ex, _sent, _ctx))

        def end_setRows(self, _r):
            return _M_omero.model.Plate._op_setRows.end(self, _r)

        def getColumns(self, _ctx=None):
            return _M_omero.model.Plate._op_getColumns.invoke(self, ((), _ctx))

        def begin_getColumns(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getColumns.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getColumns(self, _r):
            return _M_omero.model.Plate._op_getColumns.end(self, _r)

        def setColumns(self, theColumns, _ctx=None):
            return _M_omero.model.Plate._op_setColumns.invoke(self, ((theColumns, ), _ctx))

        def begin_setColumns(self, theColumns, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setColumns.begin(self, ((theColumns, ), _response, _ex, _sent, _ctx))

        def end_setColumns(self, _r):
            return _M_omero.model.Plate._op_setColumns.end(self, _r)

        def getStatus(self, _ctx=None):
            return _M_omero.model.Plate._op_getStatus.invoke(self, ((), _ctx))

        def begin_getStatus(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getStatus.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStatus(self, _r):
            return _M_omero.model.Plate._op_getStatus.end(self, _r)

        def setStatus(self, theStatus, _ctx=None):
            return _M_omero.model.Plate._op_setStatus.invoke(self, ((theStatus, ), _ctx))

        def begin_setStatus(self, theStatus, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setStatus.begin(self, ((theStatus, ), _response, _ex, _sent, _ctx))

        def end_setStatus(self, _r):
            return _M_omero.model.Plate._op_setStatus.end(self, _r)

        def getExternalIdentifier(self, _ctx=None):
            return _M_omero.model.Plate._op_getExternalIdentifier.invoke(self, ((), _ctx))

        def begin_getExternalIdentifier(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getExternalIdentifier.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getExternalIdentifier(self, _r):
            return _M_omero.model.Plate._op_getExternalIdentifier.end(self, _r)

        def setExternalIdentifier(self, theExternalIdentifier, _ctx=None):
            return _M_omero.model.Plate._op_setExternalIdentifier.invoke(self, ((theExternalIdentifier, ), _ctx))

        def begin_setExternalIdentifier(self, theExternalIdentifier, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setExternalIdentifier.begin(self, ((theExternalIdentifier, ), _response, _ex, _sent, _ctx))

        def end_setExternalIdentifier(self, _r):
            return _M_omero.model.Plate._op_setExternalIdentifier.end(self, _r)

        def unloadScreenLinks(self, _ctx=None):
            return _M_omero.model.Plate._op_unloadScreenLinks.invoke(self, ((), _ctx))

        def begin_unloadScreenLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_unloadScreenLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadScreenLinks(self, _r):
            return _M_omero.model.Plate._op_unloadScreenLinks.end(self, _r)

        def sizeOfScreenLinks(self, _ctx=None):
            return _M_omero.model.Plate._op_sizeOfScreenLinks.invoke(self, ((), _ctx))

        def begin_sizeOfScreenLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_sizeOfScreenLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfScreenLinks(self, _r):
            return _M_omero.model.Plate._op_sizeOfScreenLinks.end(self, _r)

        def copyScreenLinks(self, _ctx=None):
            return _M_omero.model.Plate._op_copyScreenLinks.invoke(self, ((), _ctx))

        def begin_copyScreenLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_copyScreenLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyScreenLinks(self, _r):
            return _M_omero.model.Plate._op_copyScreenLinks.end(self, _r)

        def addScreenPlateLink(self, target, _ctx=None):
            return _M_omero.model.Plate._op_addScreenPlateLink.invoke(self, ((target, ), _ctx))

        def begin_addScreenPlateLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addScreenPlateLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addScreenPlateLink(self, _r):
            return _M_omero.model.Plate._op_addScreenPlateLink.end(self, _r)

        def addAllScreenPlateLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Plate._op_addAllScreenPlateLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllScreenPlateLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addAllScreenPlateLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllScreenPlateLinkSet(self, _r):
            return _M_omero.model.Plate._op_addAllScreenPlateLinkSet.end(self, _r)

        def removeScreenPlateLink(self, theTarget, _ctx=None):
            return _M_omero.model.Plate._op_removeScreenPlateLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeScreenPlateLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removeScreenPlateLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeScreenPlateLink(self, _r):
            return _M_omero.model.Plate._op_removeScreenPlateLink.end(self, _r)

        def removeAllScreenPlateLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Plate._op_removeAllScreenPlateLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllScreenPlateLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removeAllScreenPlateLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllScreenPlateLinkSet(self, _r):
            return _M_omero.model.Plate._op_removeAllScreenPlateLinkSet.end(self, _r)

        def clearScreenLinks(self, _ctx=None):
            return _M_omero.model.Plate._op_clearScreenLinks.invoke(self, ((), _ctx))

        def begin_clearScreenLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_clearScreenLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearScreenLinks(self, _r):
            return _M_omero.model.Plate._op_clearScreenLinks.end(self, _r)

        def reloadScreenLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Plate._op_reloadScreenLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadScreenLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_reloadScreenLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadScreenLinks(self, _r):
            return _M_omero.model.Plate._op_reloadScreenLinks.end(self, _r)

        def getScreenLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Plate._op_getScreenLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getScreenLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getScreenLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getScreenLinksCountPerOwner(self, _r):
            return _M_omero.model.Plate._op_getScreenLinksCountPerOwner.end(self, _r)

        def linkScreen(self, addition, _ctx=None):
            return _M_omero.model.Plate._op_linkScreen.invoke(self, ((addition, ), _ctx))

        def begin_linkScreen(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_linkScreen.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkScreen(self, _r):
            return _M_omero.model.Plate._op_linkScreen.end(self, _r)

        def addScreenPlateLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Plate._op_addScreenPlateLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addScreenPlateLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addScreenPlateLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addScreenPlateLinkToBoth(self, _r):
            return _M_omero.model.Plate._op_addScreenPlateLinkToBoth.end(self, _r)

        def findScreenPlateLink(self, removal, _ctx=None):
            return _M_omero.model.Plate._op_findScreenPlateLink.invoke(self, ((removal, ), _ctx))

        def begin_findScreenPlateLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_findScreenPlateLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findScreenPlateLink(self, _r):
            return _M_omero.model.Plate._op_findScreenPlateLink.end(self, _r)

        def unlinkScreen(self, removal, _ctx=None):
            return _M_omero.model.Plate._op_unlinkScreen.invoke(self, ((removal, ), _ctx))

        def begin_unlinkScreen(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_unlinkScreen.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkScreen(self, _r):
            return _M_omero.model.Plate._op_unlinkScreen.end(self, _r)

        def removeScreenPlateLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Plate._op_removeScreenPlateLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeScreenPlateLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removeScreenPlateLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeScreenPlateLinkFromBoth(self, _r):
            return _M_omero.model.Plate._op_removeScreenPlateLinkFromBoth.end(self, _r)

        def linkedScreenList(self, _ctx=None):
            return _M_omero.model.Plate._op_linkedScreenList.invoke(self, ((), _ctx))

        def begin_linkedScreenList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_linkedScreenList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedScreenList(self, _r):
            return _M_omero.model.Plate._op_linkedScreenList.end(self, _r)

        def unloadWells(self, _ctx=None):
            return _M_omero.model.Plate._op_unloadWells.invoke(self, ((), _ctx))

        def begin_unloadWells(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_unloadWells.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadWells(self, _r):
            return _M_omero.model.Plate._op_unloadWells.end(self, _r)

        def sizeOfWells(self, _ctx=None):
            return _M_omero.model.Plate._op_sizeOfWells.invoke(self, ((), _ctx))

        def begin_sizeOfWells(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_sizeOfWells.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfWells(self, _r):
            return _M_omero.model.Plate._op_sizeOfWells.end(self, _r)

        def copyWells(self, _ctx=None):
            return _M_omero.model.Plate._op_copyWells.invoke(self, ((), _ctx))

        def begin_copyWells(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_copyWells.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyWells(self, _r):
            return _M_omero.model.Plate._op_copyWells.end(self, _r)

        def addWell(self, target, _ctx=None):
            return _M_omero.model.Plate._op_addWell.invoke(self, ((target, ), _ctx))

        def begin_addWell(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addWell.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addWell(self, _r):
            return _M_omero.model.Plate._op_addWell.end(self, _r)

        def addAllWellSet(self, targets, _ctx=None):
            return _M_omero.model.Plate._op_addAllWellSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllWellSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addAllWellSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllWellSet(self, _r):
            return _M_omero.model.Plate._op_addAllWellSet.end(self, _r)

        def removeWell(self, theTarget, _ctx=None):
            return _M_omero.model.Plate._op_removeWell.invoke(self, ((theTarget, ), _ctx))

        def begin_removeWell(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removeWell.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeWell(self, _r):
            return _M_omero.model.Plate._op_removeWell.end(self, _r)

        def removeAllWellSet(self, targets, _ctx=None):
            return _M_omero.model.Plate._op_removeAllWellSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllWellSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removeAllWellSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllWellSet(self, _r):
            return _M_omero.model.Plate._op_removeAllWellSet.end(self, _r)

        def clearWells(self, _ctx=None):
            return _M_omero.model.Plate._op_clearWells.invoke(self, ((), _ctx))

        def begin_clearWells(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_clearWells.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearWells(self, _r):
            return _M_omero.model.Plate._op_clearWells.end(self, _r)

        def reloadWells(self, toCopy, _ctx=None):
            return _M_omero.model.Plate._op_reloadWells.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadWells(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_reloadWells.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadWells(self, _r):
            return _M_omero.model.Plate._op_reloadWells.end(self, _r)

        def unloadPlateAcquisitions(self, _ctx=None):
            return _M_omero.model.Plate._op_unloadPlateAcquisitions.invoke(self, ((), _ctx))

        def begin_unloadPlateAcquisitions(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_unloadPlateAcquisitions.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadPlateAcquisitions(self, _r):
            return _M_omero.model.Plate._op_unloadPlateAcquisitions.end(self, _r)

        def sizeOfPlateAcquisitions(self, _ctx=None):
            return _M_omero.model.Plate._op_sizeOfPlateAcquisitions.invoke(self, ((), _ctx))

        def begin_sizeOfPlateAcquisitions(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_sizeOfPlateAcquisitions.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfPlateAcquisitions(self, _r):
            return _M_omero.model.Plate._op_sizeOfPlateAcquisitions.end(self, _r)

        def copyPlateAcquisitions(self, _ctx=None):
            return _M_omero.model.Plate._op_copyPlateAcquisitions.invoke(self, ((), _ctx))

        def begin_copyPlateAcquisitions(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_copyPlateAcquisitions.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyPlateAcquisitions(self, _r):
            return _M_omero.model.Plate._op_copyPlateAcquisitions.end(self, _r)

        def addPlateAcquisition(self, target, _ctx=None):
            return _M_omero.model.Plate._op_addPlateAcquisition.invoke(self, ((target, ), _ctx))

        def begin_addPlateAcquisition(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addPlateAcquisition.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addPlateAcquisition(self, _r):
            return _M_omero.model.Plate._op_addPlateAcquisition.end(self, _r)

        def addAllPlateAcquisitionSet(self, targets, _ctx=None):
            return _M_omero.model.Plate._op_addAllPlateAcquisitionSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllPlateAcquisitionSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addAllPlateAcquisitionSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllPlateAcquisitionSet(self, _r):
            return _M_omero.model.Plate._op_addAllPlateAcquisitionSet.end(self, _r)

        def removePlateAcquisition(self, theTarget, _ctx=None):
            return _M_omero.model.Plate._op_removePlateAcquisition.invoke(self, ((theTarget, ), _ctx))

        def begin_removePlateAcquisition(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removePlateAcquisition.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removePlateAcquisition(self, _r):
            return _M_omero.model.Plate._op_removePlateAcquisition.end(self, _r)

        def removeAllPlateAcquisitionSet(self, targets, _ctx=None):
            return _M_omero.model.Plate._op_removeAllPlateAcquisitionSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllPlateAcquisitionSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removeAllPlateAcquisitionSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllPlateAcquisitionSet(self, _r):
            return _M_omero.model.Plate._op_removeAllPlateAcquisitionSet.end(self, _r)

        def clearPlateAcquisitions(self, _ctx=None):
            return _M_omero.model.Plate._op_clearPlateAcquisitions.invoke(self, ((), _ctx))

        def begin_clearPlateAcquisitions(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_clearPlateAcquisitions.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearPlateAcquisitions(self, _r):
            return _M_omero.model.Plate._op_clearPlateAcquisitions.end(self, _r)

        def reloadPlateAcquisitions(self, toCopy, _ctx=None):
            return _M_omero.model.Plate._op_reloadPlateAcquisitions.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadPlateAcquisitions(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_reloadPlateAcquisitions.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadPlateAcquisitions(self, _r):
            return _M_omero.model.Plate._op_reloadPlateAcquisitions.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Plate._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Plate._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Plate._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Plate._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Plate._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Plate._op_copyAnnotationLinks.end(self, _r)

        def addPlateAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Plate._op_addPlateAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addPlateAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addPlateAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addPlateAnnotationLink(self, _r):
            return _M_omero.model.Plate._op_addPlateAnnotationLink.end(self, _r)

        def addAllPlateAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Plate._op_addAllPlateAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllPlateAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addAllPlateAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllPlateAnnotationLinkSet(self, _r):
            return _M_omero.model.Plate._op_addAllPlateAnnotationLinkSet.end(self, _r)

        def removePlateAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Plate._op_removePlateAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removePlateAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removePlateAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removePlateAnnotationLink(self, _r):
            return _M_omero.model.Plate._op_removePlateAnnotationLink.end(self, _r)

        def removeAllPlateAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Plate._op_removeAllPlateAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllPlateAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removeAllPlateAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllPlateAnnotationLinkSet(self, _r):
            return _M_omero.model.Plate._op_removeAllPlateAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Plate._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Plate._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Plate._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Plate._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Plate._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Plate._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Plate._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Plate._op_linkAnnotation.end(self, _r)

        def addPlateAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Plate._op_addPlateAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addPlateAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_addPlateAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addPlateAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Plate._op_addPlateAnnotationLinkToBoth.end(self, _r)

        def findPlateAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Plate._op_findPlateAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findPlateAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_findPlateAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findPlateAnnotationLink(self, _r):
            return _M_omero.model.Plate._op_findPlateAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Plate._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Plate._op_unlinkAnnotation.end(self, _r)

        def removePlateAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Plate._op_removePlateAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removePlateAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_removePlateAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removePlateAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Plate._op_removePlateAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Plate._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Plate._op_linkedAnnotationList.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.Plate._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.Plate._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.Plate._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.Plate._op_setName.end(self, _r)

        def getDescription(self, _ctx=None):
            return _M_omero.model.Plate._op_getDescription.invoke(self, ((), _ctx))

        def begin_getDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_getDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDescription(self, _r):
            return _M_omero.model.Plate._op_getDescription.end(self, _r)

        def setDescription(self, theDescription, _ctx=None):
            return _M_omero.model.Plate._op_setDescription.invoke(self, ((theDescription, ), _ctx))

        def begin_setDescription(self, theDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Plate._op_setDescription.begin(self, ((theDescription, ), _response, _ex, _sent, _ctx))

        def end_setDescription(self, _r):
            return _M_omero.model.Plate._op_setDescription.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.PlatePrx.ice_checkedCast(proxy, '::omero::model::Plate', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.PlatePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Plate'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_PlatePrx = IcePy.defineProxy('::omero::model::Plate', PlatePrx)

    _M_omero.model._t_Plate = IcePy.declareClass('::omero::model::Plate')

    _M_omero.model._t_Plate = IcePy.defineClass('::omero::model::Plate', Plate, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_defaultSample', (), _M_omero._t_RInt, False, 0),
        ('_columnNamingConvention', (), _M_omero._t_RString, False, 0),
        ('_rowNamingConvention', (), _M_omero._t_RString, False, 0),
        ('_wellOriginX', (), _M_omero.model._t_Length, False, 0),
        ('_wellOriginY', (), _M_omero.model._t_Length, False, 0),
        ('_rows', (), _M_omero._t_RInt, False, 0),
        ('_columns', (), _M_omero._t_RInt, False, 0),
        ('_status', (), _M_omero._t_RString, False, 0),
        ('_externalIdentifier', (), _M_omero._t_RString, False, 0),
        ('_screenLinksSeq', (), _M_omero.model._t_PlateScreenLinksSeq, False, 0),
        ('_screenLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_screenLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_wellsSeq', (), _M_omero.model._t_PlateWellsSeq, False, 0),
        ('_wellsLoaded', (), IcePy._t_bool, False, 0),
        ('_plateAcquisitionsSeq', (), _M_omero.model._t_PlatePlateAcquisitionsSeq, False, 0),
        ('_plateAcquisitionsLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_PlateAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0),
        ('_description', (), _M_omero._t_RString, False, 0)
    ))
    Plate._ice_type = _M_omero.model._t_Plate

    Plate._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Plate._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Plate._op_getDefaultSample = IcePy.Operation('getDefaultSample', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Plate._op_setDefaultSample = IcePy.Operation('setDefaultSample', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Plate._op_getColumnNamingConvention = IcePy.Operation('getColumnNamingConvention', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Plate._op_setColumnNamingConvention = IcePy.Operation('setColumnNamingConvention', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Plate._op_getRowNamingConvention = IcePy.Operation('getRowNamingConvention', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Plate._op_setRowNamingConvention = IcePy.Operation('setRowNamingConvention', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Plate._op_getWellOriginX = IcePy.Operation('getWellOriginX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    Plate._op_setWellOriginX = IcePy.Operation('setWellOriginX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    Plate._op_getWellOriginY = IcePy.Operation('getWellOriginY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    Plate._op_setWellOriginY = IcePy.Operation('setWellOriginY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    Plate._op_getRows = IcePy.Operation('getRows', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Plate._op_setRows = IcePy.Operation('setRows', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Plate._op_getColumns = IcePy.Operation('getColumns', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Plate._op_setColumns = IcePy.Operation('setColumns', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Plate._op_getStatus = IcePy.Operation('getStatus', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Plate._op_setStatus = IcePy.Operation('setStatus', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Plate._op_getExternalIdentifier = IcePy.Operation('getExternalIdentifier', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Plate._op_setExternalIdentifier = IcePy.Operation('setExternalIdentifier', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Plate._op_unloadScreenLinks = IcePy.Operation('unloadScreenLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Plate._op_sizeOfScreenLinks = IcePy.Operation('sizeOfScreenLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Plate._op_copyScreenLinks = IcePy.Operation('copyScreenLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlateScreenLinksSeq, False, 0), ())
    Plate._op_addScreenPlateLink = IcePy.Operation('addScreenPlateLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLink, False, 0),), (), None, ())
    Plate._op_addAllScreenPlateLinkSet = IcePy.Operation('addAllScreenPlateLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateScreenLinksSeq, False, 0),), (), None, ())
    Plate._op_removeScreenPlateLink = IcePy.Operation('removeScreenPlateLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLink, False, 0),), (), None, ())
    Plate._op_removeAllScreenPlateLinkSet = IcePy.Operation('removeAllScreenPlateLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateScreenLinksSeq, False, 0),), (), None, ())
    Plate._op_clearScreenLinks = IcePy.Operation('clearScreenLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Plate._op_reloadScreenLinks = IcePy.Operation('reloadScreenLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Plate, False, 0),), (), None, ())
    Plate._op_getScreenLinksCountPerOwner = IcePy.Operation('getScreenLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Plate._op_linkScreen = IcePy.Operation('linkScreen', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Screen, False, 0),), (), ((), _M_omero.model._t_ScreenPlateLink, False, 0), ())
    Plate._op_addScreenPlateLinkToBoth = IcePy.Operation('addScreenPlateLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Plate._op_findScreenPlateLink = IcePy.Operation('findScreenPlateLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Screen, False, 0),), (), ((), _M_omero.model._t_PlateScreenLinksSeq, False, 0), ())
    Plate._op_unlinkScreen = IcePy.Operation('unlinkScreen', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Screen, False, 0),), (), None, ())
    Plate._op_removeScreenPlateLinkFromBoth = IcePy.Operation('removeScreenPlateLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Plate._op_linkedScreenList = IcePy.Operation('linkedScreenList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlateLinkedScreenSeq, False, 0), ())
    Plate._op_unloadWells = IcePy.Operation('unloadWells', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Plate._op_sizeOfWells = IcePy.Operation('sizeOfWells', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Plate._op_copyWells = IcePy.Operation('copyWells', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlateWellsSeq, False, 0), ())
    Plate._op_addWell = IcePy.Operation('addWell', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Well, False, 0),), (), None, ())
    Plate._op_addAllWellSet = IcePy.Operation('addAllWellSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateWellsSeq, False, 0),), (), None, ())
    Plate._op_removeWell = IcePy.Operation('removeWell', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Well, False, 0),), (), None, ())
    Plate._op_removeAllWellSet = IcePy.Operation('removeAllWellSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateWellsSeq, False, 0),), (), None, ())
    Plate._op_clearWells = IcePy.Operation('clearWells', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Plate._op_reloadWells = IcePy.Operation('reloadWells', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Plate, False, 0),), (), None, ())
    Plate._op_unloadPlateAcquisitions = IcePy.Operation('unloadPlateAcquisitions', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Plate._op_sizeOfPlateAcquisitions = IcePy.Operation('sizeOfPlateAcquisitions', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Plate._op_copyPlateAcquisitions = IcePy.Operation('copyPlateAcquisitions', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlatePlateAcquisitionsSeq, False, 0), ())
    Plate._op_addPlateAcquisition = IcePy.Operation('addPlateAcquisition', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisition, False, 0),), (), None, ())
    Plate._op_addAllPlateAcquisitionSet = IcePy.Operation('addAllPlateAcquisitionSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlatePlateAcquisitionsSeq, False, 0),), (), None, ())
    Plate._op_removePlateAcquisition = IcePy.Operation('removePlateAcquisition', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisition, False, 0),), (), None, ())
    Plate._op_removeAllPlateAcquisitionSet = IcePy.Operation('removeAllPlateAcquisitionSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlatePlateAcquisitionsSeq, False, 0),), (), None, ())
    Plate._op_clearPlateAcquisitions = IcePy.Operation('clearPlateAcquisitions', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Plate._op_reloadPlateAcquisitions = IcePy.Operation('reloadPlateAcquisitions', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Plate, False, 0),), (), None, ())
    Plate._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Plate._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Plate._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlateAnnotationLinksSeq, False, 0), ())
    Plate._op_addPlateAnnotationLink = IcePy.Operation('addPlateAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAnnotationLink, False, 0),), (), None, ())
    Plate._op_addAllPlateAnnotationLinkSet = IcePy.Operation('addAllPlateAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAnnotationLinksSeq, False, 0),), (), None, ())
    Plate._op_removePlateAnnotationLink = IcePy.Operation('removePlateAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAnnotationLink, False, 0),), (), None, ())
    Plate._op_removeAllPlateAnnotationLinkSet = IcePy.Operation('removeAllPlateAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAnnotationLinksSeq, False, 0),), (), None, ())
    Plate._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Plate._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Plate, False, 0),), (), None, ())
    Plate._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Plate._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_PlateAnnotationLink, False, 0), ())
    Plate._op_addPlateAnnotationLinkToBoth = IcePy.Operation('addPlateAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Plate._op_findPlateAnnotationLink = IcePy.Operation('findPlateAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_PlateAnnotationLinksSeq, False, 0), ())
    Plate._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Plate._op_removePlateAnnotationLinkFromBoth = IcePy.Operation('removePlateAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Plate._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlateLinkedAnnotationSeq, False, 0), ())
    Plate._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Plate._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Plate._op_getDescription = IcePy.Operation('getDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Plate._op_setDescription = IcePy.Operation('setDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.Plate = Plate
    del Plate

    _M_omero.model.PlatePrx = PlatePrx
    del PlatePrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `LaserMedium.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

# Start of module omero.model.enums
_M_omero.model.enums = Ice.openModule('omero.model.enums')
__name__ = 'omero.model.enums'

_M_omero.model.enums.LaserMediumRhodamine6G = "Rhodamine6G"

_M_omero.model.enums.LaserMediumCoumarinC30 = "CoumarinC30"

_M_omero.model.enums.LaserMediumArFl = "ArFl"

_M_omero.model.enums.LaserMediumArCl = "ArCl"

_M_omero.model.enums.LaserMediumKrFl = "KrFl"

_M_omero.model.enums.LaserMediumKrCl = "KrCl"

_M_omero.model.enums.LaserMediumXeFl = "XeFl"

_M_omero.model.enums.LaserMediumXeCl = "XeCl"

_M_omero.model.enums.LaserMediumXeBr = "XeBr"

_M_omero.model.enums.LaserMediumGaAs = "GaAs"

_M_omero.model.enums.LaserMediumGaAlAs = "GaAlAs"

_M_omero.model.enums.LaserMediumEMinus = "EMinus"

_M_omero.model.enums.LaserMediumCu = "Cu"

_M_omero.model.enums.LaserMediumAg = "Ag"

_M_omero.model.enums.LaserMediumN = "N"

_M_omero.model.enums.LaserMediumAr = "Ar"

_M_omero.model.enums.LaserMediumKr = "Kr"

_M_omero.model.enums.LaserMediumXe = "Xe"

_M_omero.model.enums.LaserMediumHeNe = "HeNe"

_M_omero.model.enums.LaserMediumHeCd = "HeCd"

_M_omero.model.enums.LaserMediumCO = "CO"

_M_omero.model.enums.LaserMediumCO2 = "CO2"

_M_omero.model.enums.LaserMediumH2O = "H2O"

_M_omero.model.enums.LaserMediumHFl = "HFl"

_M_omero.model.enums.LaserMediumNdGlass = "NdGlass"

_M_omero.model.enums.LaserMediumNdYAG = "NdYAG"

_M_omero.model.enums.LaserMediumErGlass = "ErGlass"

_M_omero.model.enums.LaserMediumErYAG = "ErYAG"

_M_omero.model.enums.LaserMediumHoYLF = "HoYLF"

_M_omero.model.enums.LaserMediumHoYAG = "HoYAG"

_M_omero.model.enums.LaserMediumRuby = "Ruby"

_M_omero.model.enums.LaserMediumTiSapphire = "TiSapphire"

_M_omero.model.enums.LaserMediumAlexandrite = "Alexandrite"

_M_omero.model.enums.LaserMediumOther = "Other"

_M_omero.model.enums.LaserMediumUnknown = "Unknown"

# End of module omero.model.enums

__name__ = 'omero.model'

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'LaserMedium' not in _M_omero.model.__dict__:
    _M_omero.model.LaserMedium = Ice.createTempClass()
    class LaserMedium(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _value=None):
            if Ice.getType(self) == _M_omero.model.LaserMedium:
                raise RuntimeError('omero.model.LaserMedium is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._value = _value

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::LaserMedium')

        def ice_id(self, current=None):
            return '::omero::model::LaserMedium'

        def ice_staticId():
            return '::omero::model::LaserMedium'
        ice_staticId = staticmethod(ice_staticId)

        def getValue(self, current=None):
            pass

        def setValue(self, theValue, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_LaserMedium)

        __repr__ = __str__

    _M_omero.model.LaserMediumPrx = Ice.createTempClass()
    class LaserMediumPrx(_M_omero.model.IObjectPrx):

        def getValue(self, _ctx=None):
            return _M_omero.model.LaserMedium._op_getValue.invoke(self, ((), _ctx))

        def begin_getValue(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LaserMedium._op_getValue.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getValue(self, _r):
            return _M_omero.model.LaserMedium._op_getValue.end(self, _r)

        def setValue(self, theValue, _ctx=None):
            return _M_omero.model.LaserMedium._op_setValue.invoke(self, ((theValue, ), _ctx))

        def begin_setValue(self, theValue, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LaserMedium._op_setValue.begin(self, ((theValue, ), _response, _ex, _sent, _ctx))

        def end_setValue(self, _r):
            return _M_omero.model.LaserMedium._op_setValue.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.LaserMediumPrx.ice_checkedCast(proxy, '::omero::model::LaserMedium', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.LaserMediumPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::LaserMedium'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_LaserMediumPrx = IcePy.defineProxy('::omero::model::LaserMedium', LaserMediumPrx)

    _M_omero.model._t_LaserMedium = IcePy.declareClass('::omero::model::LaserMedium')

    _M_omero.model._t_LaserMedium = IcePy.defineClass('::omero::model::LaserMedium', LaserMedium, -1, (), True, False, _M_omero.model._t_IObject, (), (('_value', (), _M_omero._t_RString, False, 0),))
    LaserMedium._ice_type = _M_omero.model._t_LaserMedium

    LaserMedium._op_getValue = IcePy.Operation('getValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    LaserMedium._op_setValue = IcePy.Operation('setValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.LaserMedium = LaserMedium
    del LaserMedium

    _M_omero.model.LaserMediumPrx = LaserMediumPrx
    del LaserMediumPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
